using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Portable;

namespace ThinkGeo.MapSuite.Styles
{
    public static class WorldStreetsLineStyles
    {
        public static LineStyle Water(float outerWidth)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 160, 207, 235), outerWidth));
            lineStyle.StyleClass = "WorldStreetsLineStyles.Water";

            return lineStyle;
        }

        public static LineStyle Bridge(float outerWidth)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 153, 153, 153), outerWidth));
            lineStyle.StyleClass = "WorldStreetsLineStyles.Bridge";

            return lineStyle;
        }

        public static LineStyle Rail(float outerWidth, float innerWidth, float centerWidth)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 204, 204, 204), outerWidth), new GeoPen(new GeoColor(255, 250, 247, 243), innerWidth), new GeoPen(new GeoColor(255, 204, 204, 204), centerWidth));

            lineStyle.CenterPen.DashPattern.Add(0.4f);
            lineStyle.CenterPen.DashPattern.Add(1.5f);

            lineStyle.CenterPenDrawingLevel = DrawingLevel.LevelOne;
            lineStyle.InnerPenDrawingLevel = DrawingLevel.LevelOne;
            lineStyle.OuterPenDrawingLevel = DrawingLevel.LevelOne;

            lineStyle.StyleClass = "WorldStreetsLineStyles.Rail";
            return lineStyle;
        }

        public static LineStyle Subway(float outerWidth, float innerWidth, float centerWidth)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 204, 204, 204), outerWidth), new GeoPen(new GeoColor(255, 225, 225, 225), innerWidth), new GeoPen(new GeoColor(255, 204, 204, 204), centerWidth));

            lineStyle.CenterPen.DashPattern.Add(0.4f);
            lineStyle.CenterPen.DashPattern.Add(1.5f);

            lineStyle.CenterPenDrawingLevel = DrawingLevel.LevelOne;
            lineStyle.InnerPenDrawingLevel = DrawingLevel.LevelOne;
            lineStyle.OuterPenDrawingLevel = DrawingLevel.LevelOne;

            lineStyle.StyleClass = "WorldStreetsLineStyles.Subway";
            return lineStyle;
        }

        public static LineStyle Monorail(float outerWidth, float innerWidth, float centerWidth)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 225, 225, 225), outerWidth), new GeoPen(new GeoColor(255, 250, 250, 250), innerWidth), new GeoPen(new GeoColor(255, 204, 204, 204), centerWidth));

            lineStyle.CenterPenDrawingLevel = DrawingLevel.LevelOne;
            lineStyle.InnerPenDrawingLevel = DrawingLevel.LevelOne;
            lineStyle.OuterPenDrawingLevel = DrawingLevel.LevelOne;

            lineStyle.StyleClass = "WorldStreetsLineStyles.Monorail";
            return lineStyle;
        }

        public static LineStyle MiniRail(float outerWidth, float innerWidth, float centerWidth)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 204, 204, 204), outerWidth), new GeoPen(new GeoColor(255, 250, 247, 243), innerWidth), new GeoPen(new GeoColor(255, 204, 204, 204), centerWidth));

            lineStyle.CenterPen.DashPattern.Add(0.25f);
            lineStyle.CenterPen.DashPattern.Add(1f);

            lineStyle.CenterPenDrawingLevel = DrawingLevel.LevelOne;
            lineStyle.InnerPenDrawingLevel = DrawingLevel.LevelOne;
            lineStyle.OuterPenDrawingLevel = DrawingLevel.LevelOne;

            lineStyle.StyleClass = "WorldStreetsLineStyles.MiniRail";
            return lineStyle;
        }

        public static LineStyle PowerLine(float outerWidth)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 164, 163, 161), outerWidth));
            lineStyle.StyleClass = "WorldStreetsLineStyles.PowerLine";

            return lineStyle;
        }

        public static LineStyle Apron(float outerWidth)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 233, 212, 254), outerWidth) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.Apron";

            return lineStyle;
        }

        public static LineStyle Runway(float outerWidth)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 188, 188, 205), outerWidth) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.Runway";

            return lineStyle;
        }

        public static LineStyle Taxiway(float outerWidth)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 193, 193, 210), outerWidth) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.Taxiway";

            return lineStyle;
        }

        public static LineStyle Pier(float outerWidth)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 250, 248, 246), outerWidth) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.Pier";

            return lineStyle;
        }

        public static LineStyle CableCar(float outerWidth)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 132, 132, 132), outerWidth) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.CableCar";

            return lineStyle;
        }

        public static LineStyle Highway(float outerWidth)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 255, 222, 190), outerWidth) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.Highway";

            return lineStyle;
        }

        public static LineStyle BoundaryMinor(float outerWidth)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 225, 225, 225), outerWidth));
            lineStyle.StyleClass = "WorldStreetsLineStyles.BoundaryMinor";

            return lineStyle;
        }

        public static LineStyle Boundary(float outerWidth)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 204, 204, 204), outerWidth));
            lineStyle.StyleClass = "WorldStreetsLineStyles.Boundary";

            return lineStyle;
        }

        public static LineStyle BoundaryNational(float outerWidth)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 190, 175, 190), outerWidth) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.BoundaryNational";

            return lineStyle;
        }

        public static LineStyle BoundaryState(float outerWidth)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 190, 175, 190), outerWidth));
            lineStyle.OuterPen.StartCap = DrawingLineCap.Round;
            lineStyle.OuterPen.EndCap = DrawingLineCap.Round;

            //lineStyle.OuterPen.DashStyle = LineDashStyle.Custom;
            //lineStyle.OuterPen.DashPattern.Add(5);
            //lineStyle.OuterPen.DashPattern.Add(2);

            lineStyle.StyleClass = "WorldStreetsLineStyles.BoundaryState";
            return lineStyle;
        }

        public static LineStyle BoundaryCounty(float outerWidth)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 190, 175, 190), outerWidth));
            lineStyle.OuterPen.StartCap = DrawingLineCap.Round;
            lineStyle.OuterPen.EndCap = DrawingLineCap.Round;

            //lineStyle.OuterPen.DashStyle = LineDashStyle.Custom;
            //lineStyle.OuterPen.DashPattern.Add(4);
            //lineStyle.OuterPen.DashPattern.Add(2);

            lineStyle.StyleClass = "WorldStreetsLineStyles.BoundaryCounty";
            return lineStyle;
        }

        public static LineStyle BoundaryCity(float outerWidth)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 190, 175, 190), outerWidth));
            lineStyle.OuterPen.StartCap = DrawingLineCap.Round;
            lineStyle.OuterPen.EndCap = DrawingLineCap.Round;

            //lineStyle.OuterPen.DashStyle = LineDashStyle.Custom;
            //lineStyle.OuterPen.DashPattern.Add(3);
            //lineStyle.OuterPen.DashPattern.Add(2);

            lineStyle.StyleClass = "WorldStreetsLineStyles.BoundaryCity";
            return lineStyle;
        }

        public static LineStyle MotorwayOutline(float width)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 225, 183, 122), width) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.MotorwayOutline";

            return lineStyle;
        }

        public static LineStyle MotorwayFill(float width)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 247, 195, 128), width) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.MotorwayFill";

            return lineStyle;
        }

        public static LineStyle TrunkOutline(float width)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 225, 205, 168), width) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.TrunkOutline";

            return lineStyle;
        }

        public static LineStyle TrunkFill(float width)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 245, 231, 202), width) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.TrunkFill";

            return lineStyle;
        }

        public static LineStyle PrimaryOutline(float width)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 204, 204, 204), width) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.PrimaryOutline";

            return lineStyle;
        }

        public static LineStyle PrimaryFill(float width)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 250, 246, 225), width) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.PrimaryFill";

            return lineStyle;
        }

        public static LineStyle RoadOutline(float width)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 225, 225, 225), width) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.RoadOutline";

            return lineStyle;
        }

        public static LineStyle RoadFill(float width)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 255, 255, 255), width) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.RoadFill";

            return lineStyle;
        }

        public static LineStyle MotorwayLinkOutline(float width)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 225, 182, 120), width) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.MotorwayLinkOutline";

            return lineStyle;
        }

        public static LineStyle MotorwayLinkFill(float width)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 247, 221, 185), width) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.MotorwayLinkFill";

            return lineStyle;
        }

        public static LineStyle TrunkLinkOutline(float width)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 226, 208, 172), width) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.TrunkLinkOutline";

            return lineStyle;
        }

        public static LineStyle TrunkLinkFill(float width)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 250, 242, 225), width) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.TrunkLinkFill";

            return lineStyle;
        }

        public static LineStyle PrimaryLinkOutline(float width)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 204, 204, 204), width) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.PrimaryLinkOutline";

            return lineStyle;
        }

        public static LineStyle PrimaryLinkFill(float width)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 250, 246, 225), width) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.PrimaryLinkFill";

            return lineStyle;
        }

        public static LineStyle MinorRoadOutline(float width)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 204, 204, 204), width) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.MinorRoadOutline";

            return lineStyle;
        }

        public static LineStyle MinorRoadFill(float width)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 240, 239, 238), width) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.MinorRoadFill";

            return lineStyle;
        }

        public static LineStyle StepsOutline(float width)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 204, 204, 204), width) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round });
            lineStyle.StyleClass = "WorldStreetsLineStyles.StepsOutline";

            return lineStyle;
        }

        public static LineStyle StepsFill(float width)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 240, 239, 238), width) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round, DashStyle = LineDashStyle.Dot });
            lineStyle.StyleClass = "WorldStreetsLineStyles.StepsFill";

            return lineStyle;
        }

        public static LineStyle Tunnel(float width)
        {
            LineStyle lineStyle = new LineStyle(new GeoPen(new GeoColor(255, 153, 153, 153), width + 2) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round }, new GeoPen(new GeoColor(225, 204, 204, 204), width + 2) { StartCap = DrawingLineCap.Round, EndCap = DrawingLineCap.Round, DashStyle = LineDashStyle.Dot }) { InnerPenDrawingLevel = DrawingLevel.LevelOne };
            lineStyle.StyleClass = "WorldStreetsLineStyles.Tunnel";

            return lineStyle;
        }

        public static LineStyle OneWay(string columnName, string columnValue, string iconPath)
        {
            LineStyle lineStyle = new OneWayLineStyle(columnName, columnValue, new GeoImage(PclSystem.Path.Combine(iconPath, "highwayoneway.16.png")));
            lineStyle.StyleClass = "WorldStreetsLineStyles.OneWay";

            return lineStyle;
        }
    }
}