using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Portable;

namespace ThinkGeo.MapSuite.Styles
{
    public static class WorldStreetsPointStyles
    {
        public static PointStyle PowerPole()
        {
            return new PointStyle()
            {
                PointType = PointType.Symbol,
                SymbolType = PointSymbolType.Square,
                SymbolPen = new GeoPen(new GeoColor(255, 153, 153, 153)),
                SymbolSolidBrush = new GeoSolidBrush(new GeoColor(255, 204, 204, 204)),
                SymbolSize = 3,
                StyleClass = "WorldStreetsPointStyles.PowerPole"
            };
        }

        private static PointStyle ImagePointStyle(string iconPathFilename)
        {
            return new PointStyle()
            {
                PointType = PointType.Bitmap,
                Image = new GeoImage(iconPathFilename),
                DrawingLevel = DrawingLevel.LabelLevel,
                StyleClass = "WorldStreetsPointStyles." + PclSystem.Path.GetFileNameWithoutExtension(PclSystem.Path.GetFileNameWithoutExtension(iconPathFilename))
            };
        }

        public static PointStyle AerowayTerminal(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "aerowayterminal.16.png"));
        }

        public static PointStyle AerowayHelipad(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "aerowayhelipad.16.png"));
        }

        public static PointStyle AerowayGate(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "aerowaygate.16.png"));
        }

        public static PointStyle AerowayAerodrome(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "aerowayaerodrome.16.png"));
        }

        public static PointStyle AmenityToiletsDisabilityAccess(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitytoilets-disabled.16.png"));
        }

        public static PointStyle AmenityBar(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitybar.16.png"));
        }

        public static PointStyle AmenityToiletsGenderAccessMen(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitytoilets-men.16.png"));
        }

        public static PointStyle AmenityToiletsGenderAccessWomen(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitytoilets-women.16.png"));
        }

        public static PointStyle AmenityToilets(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitytoilets.16.png"));
        }

        public static PointStyle AmenityWasteDisposal(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitywaste_disposal.16.png"));
        }

        public static PointStyle AmenityVeterinary(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityveterinary.16.png"));
        }

        public static PointStyle AmenityVendingMachine(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityvending_machine.16.png"));
        }

        public static PointStyle AmenityUniversity(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityuniversity.16.png"));
        }

        public static PointStyle AmenityTownHall(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitytownhall-2.16.png"));
        }

        public static PointStyle AmenityTheatre(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitytheatre.16.png"));
        }

        public static PointStyle AmenityTelephone(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitytelephone.16.png"));
        }

        public static PointStyle AmenityTaxi(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitytaxi.16.png"));
        }

        public static PointStyle AmenityShelter(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityshelter-2.16.png"));
        }

        public static PointStyle AmenitySchool(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityschool.16.png"));
        }

        public static PointStyle AmenityRestaurant(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityrestaurant.16.png"));
        }

        public static PointStyle AmenityRecycling(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityrecycling.16.png"));
        }

        public static PointStyle AmenityPub(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitypub.16.png"));
        }

        public static PointStyle AmenityPrison(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityprison.16.png"));
        }

        public static PointStyle AmenityPostOffice(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitypost_office.16.png"));
        }

        public static PointStyle AmenityPostBox(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitypost_box.16.png"));
        }

        public static PointStyle AmenityPolice(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitypolice-2.16.png"));
        }

        public static PointStyle AmenityNursingHome(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitynursing_home.16.png"));
        }

        public static PointStyle AmenityLibrary(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitylibrary-2.16.png"));
        }

        public static PointStyle AmenityIceCream(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityice_cream.16.png"));
        }

        public static PointStyle AmenityFountain(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityfountain-2.16.png"));
        }

        public static PointStyle AmenityFireStation(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityfire_station-2.16.png"));
        }

        public static PointStyle AmenityEmbassy(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityembassy.16.png"));
        }

        public static PointStyle AmenityDrinkingWater(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitydrinking_water.16.png"));
        }

        public static PointStyle AmenityDoctors(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitydoctors.16.png"));
        }

        public static PointStyle AmenityDentist(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitydentist.16.png"));
        }

        public static PointStyle AmenityCourtHouse(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitycourthouse.16.png"));
        }

        public static PointStyle AmenityCollege(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitycollege.16.png"));
        }

        public static PointStyle AmenityClock(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityclock.16.png"));
        }

        public static PointStyle AmenityCinema(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitycinema-2.16.png"));
        }

        public static PointStyle AmenityCarRental(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitycar_rental.16.png"));
        }

        public static PointStyle AmenityCafe(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitycafe.16.png"));
        }

        public static PointStyle AmenityBusStation(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitybus_station.16.png"));
        }

        public static PointStyle AmenityBiergarten(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitybiergarten.16.png"));
        }

        public static PointStyle AmenityBicycleRental(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitybicycle_rental.16.png"));
        }

        public static PointStyle AmenityBicycleParking(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityparking-bicycle.16.png"));
        }

        public static PointStyle AmenityBench(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitybench.16.png"));
        }

        public static PointStyle AmenityPlaceOfWorshipSikh(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityplace_of_worship-sikh-3.16.png"));
        }

        public static PointStyle AmenityPlaceOfWorshipShinto(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityplace_of_worship-shinto-3.16.png"));
        }

        public static PointStyle AmenityPlaceOfWorshipJewish(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityplace_of_worship-jewish-3.16.png"));
        }

        public static PointStyle AmenityPlaceOfWorshipJain(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityplace_of_worship-jain-3.16.png"));
        }

        public static PointStyle AmenityPlaceOfWorshipIslamic(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityplace_of_worship-islamic-3.16.png"));
        }

        public static PointStyle AmenityPlaceOfWorshipHindu(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityplace_of_worship-hindu-3.16.png"));
        }

        public static PointStyle AmenityPlaceOfWorshipChristian(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityplace_of_worship-christian-3.16.png"));
        }

        public static PointStyle AmenityPlaceOfWorshipBuddhist(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityplace_of_worship-buddhist-3.16.png"));
        }

        public static PointStyle AmenityPlaceOfWorship(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityplace_of_worship-unknown-3.16.png"));
        }

        public static PointStyle AmenityPharmacyDispencing(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitypharmacy-dispencing.16.png"));
        }

        public static PointStyle AmenityPharmacy(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitypharmacy.16.png"));
        }

        public static PointStyle AmenityParkingPrivate(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityparking-private.16.png"));
        }

        public static PointStyle AmenityParkingCarPaid(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityparking-car_paid.16.png"));
        }

        public static PointStyle AmenityParkingDisabled(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityparking-disabled.16.png"));
        }

        public static PointStyle AmenityParking(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityparking.16.png"));
        }

        public static PointStyle AmenityHospitalEmergency(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityhospital-emergency2.16.png"));
        }

        public static PointStyle AmenityHospital(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityhospital.16.png"));
        }

        public static PointStyle AmenityFuelLpg(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityfuel-lpg.16.png"));
        }

        public static PointStyle AmenityFuel(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityfuel.16.png"));
        }

        public static PointStyle AmenityFastFoodPizza(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityfast_food-pizza.16.png"));
        }

        public static PointStyle AmenityFastFood(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenityfast_food.16.png"));
        }

        public static PointStyle BarrierTollbooth(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "barriertoll_booth.16.png"));
        }

        public static PointStyle BarrierStile(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "barrierstile.16.png"));
        }

        public static PointStyle BarrierLiftGate(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "barrierlift_gate.16.png"));
        }

        public static PointStyle BarrierKissingGate(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "barrierkissing_gate.16.png"));
        }

        public static PointStyle BarrierGate(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "barriergate.16.png"));
        }

        public static PointStyle BarrierEntrance(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "barrierentrance.16.png"));
        }

        public static PointStyle BarrierCycleBarrier(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "barriercycle_barrier.16.png"));
        }

        public static PointStyle BarrierCattleGrid(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "barriercattle_grid.16.png"));
        }

        public static PointStyle BarrierBollard(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "barrierbollard.16.png"));
        }

        public static PointStyle BarrierBlock(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "barrierblock.16.png"));
        }

        public static PointStyle Ford(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "fordyes.16.png"));
        }

        public static PointStyle HistoricWreck(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "historicwreck.16.png"));
        }

        public static PointStyle HistoricWayside_Shrine(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "historicwayside_shrine.16.png"));
        }

        public static PointStyle HistoricWaysideCross(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "historicwayside_cross.16.png"));
        }

        public static PointStyle HistoricRuins(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "historicruins.16.png"));
        }

        public static PointStyle HistoricMonument(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "historicmonument.16.png"));
        }

        public static PointStyle HistoricMemorial(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "historicmemorial.16.png"));
        }

        public static PointStyle HistoricCastle(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "historiccastle-2.16.png"));
        }

        public static PointStyle HistoricBattlefield(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "historicbattlefield.16.png"));
        }

        public static PointStyle HighwayTrafficSignals(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "highwaytraffic_signals.16.png"));
        }

        public static PointStyle HighwayBusStop(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "highwaybus_stop-2.16.png"));
        }

        public static PointStyle HighwayMiniRoundaboutAnticlockwise(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "highwaymini_roundabout-anticlockwise.16.png"));
        }

        public static PointStyle HighwayMiniRoundaboutClockwise(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "highwaymini_roundabout-clockwise.16.png"));
        }

        public static PointStyle LeisureStadium(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "leisurestadium.16.png"));
        }

        public static PointStyle LeisureSlipway(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "leisureslipway.16.png"));
        }

        public static PointStyle LeisureMarina(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "leisuremarina.16.png"));
        }

        public static PointStyle ManMadeWindmill(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "man_madewindmill.16.png"));
        }

        public static PointStyle ManMadeWaterTower(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "man_madewater_tower.16.png"));
        }

        public static PointStyle ManMadeLighthouse(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "man_madelighthouse.16.png"));
        }

        public static PointStyle ManMadeCrane(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "man_madecrane.16.png"));
        }

        public static PointStyle ManMadeMineshaftAbandoned(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "man_mademineshaft-abandoned.16.png"));
        }

        public static PointStyle ManMadeMineshaft(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "man_mademineshaft.16.png"));
        }

        public static PointStyle MilitaryBunker(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "militarybunker.16.png"));
        }

        public static PointStyle NaturalPeak(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "naturalpeak-2.16.png"));
        }

        public static PointStyle NaturalCave(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "naturalcave.16.png"));
        }

        public static PointStyle NaturalWoodConiferous(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "naturalwood-coniferous.16.png"));
        }

        public static PointStyle NaturalWoodDeciduous(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "naturalwood-deciduous.16.png"));
        }

        public static PointStyle NaturalWoodMixed(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "naturalwood-mixed.16.png"));
        }

        public static PointStyle OfficeEstateAgent(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "officeestate_agent-2.16.png"));
        }

        public static PointStyle PowerTower(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "powertower.16.png"));
        }

        public static PointStyle PowerSubStation(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "powersub_station.16.png"));
        }

        public static PointStyle PowerPlantHydro(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "powerplant-water.16.png"));
        }

        public static PointStyle PowerPlantGas(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "powerplant-gas.16.png"));
        }

        public static PointStyle PowerPlantSolar(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "powerplant-solar.16.png"));
        }

        public static PointStyle PowerPlantWind(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "powerplant-wind.16.png"));
        }

        public static PointStyle PowerPlantCoal(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "powerplant-coal.16.png"));
        }

        public static PointStyle RailwayTramStop(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "railwaytram_stop.16.png"));
        }

        public static PointStyle RailwaySubway(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "railwaysubway.16.png"));
        }

        public static PointStyle ShopVideo(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopvideo.16.png"));
        }

        public static PointStyle ShopToys(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shoptoys.16.png"));
        }

        public static PointStyle ShopTobacco(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shoptobacco.16.png"));
        }

        public static PointStyle ShopSupermarket(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopsupermarket.16.png"));
        }

        public static PointStyle ShopPet(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shoppet-2.16.png"));
        }

        public static PointStyle ShopOptician(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopoptician.16.png"));
        }

        public static PointStyle ShopNewsagent(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopnewsagent.16.png"));
        }

        public static PointStyle ShopMusicalInstrument(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopmusic.16.png"));
        }

        public static PointStyle ShopMotorcycle(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopmotorcycle.16.png"));
        }

        public static PointStyle ShopMobliePhone(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopmobile_phone.16.png"));
        }

        public static PointStyle ShopLaundry(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shoplaundry.16.png"));
        }

        public static PointStyle ShopKiosk(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopkiosk.16.png"));
        }

        public static PointStyle ShopJewelry(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopjewelry.16.png"));
        }

        public static PointStyle ShopHifi(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shophifi.16.png"));
        }

        public static PointStyle ShopHearingAids(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shophearing_aids.16.png"));
        }

        public static PointStyle ShopHairdresser(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shophairdresser.16.png"));
        }

        public static PointStyle ShopGreengrocer(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopgreengrocer.16.png"));
        }

        public static PointStyle ShopGift(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopgift.16.png"));
        }

        public static PointStyle ShopGardenCentre(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopgarden_centre.16.png"));
        }

        public static PointStyle ShopFlorist(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopflorist.16.png"));
        }

        public static PointStyle ShopDoItYourself(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopdoityourself.16.png"));
        }

        public static PointStyle ShopDepartmentStore(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopdepartment_store.16.png"));
        }

        public static PointStyle ShopCopyshop(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopcopyshop.16.png"));
        }

        public static PointStyle ShopConvenience(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopconvenience.16.png"));
        }

        public static PointStyle ShopConfectionery(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopconfectionery.16.png"));
        }

        public static PointStyle ShopComputer(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopcomputer.16.png"));
        }

        public static PointStyle ShopClothes(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopclothes.16.png"));
        }

        public static PointStyle ShopCar(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopcar.16.png"));
        }

        public static PointStyle ShopCarRepair(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopcar_repair.16.png"));
        }

        public static PointStyle ShopButcher(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopbutcher.16.png"));
        }

        public static PointStyle ShopBooks(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopbooks.16.png"));
        }

        public static PointStyle ShopBicycle(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopbicycle.16.png"));
        }

        public static PointStyle ShopBakery(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopbakery.16.png"));
        }

        public static PointStyle ShopAlcohol(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "shopalcohol.16.png"));
        }

        public static PointStyle SportTennis(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "sporttennis.16.png"));
        }

        public static PointStyle SportSoccer(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "sportsoccer.16.png"));
        }

        public static PointStyle SportShooting(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "sportshooting.16.png"));
        }

        public static PointStyle SportMotor(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "sportmotor.16.png"));
        }

        public static PointStyle SportIceStock(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "sportice_stock.16.png"));
        }

        public static PointStyle SportHorseRacing(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "sporthorse_racing.16.png"));
        }

        public static PointStyle SportGymnastics(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "sportgymnastics-2.16.png"));
        }

        public static PointStyle SportGolf(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "sportgolf.16.png"));
        }

        public static PointStyle SportDiving(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "sportdiving.16.png"));
        }

        public static PointStyle SportCricket(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "sportcricket.16.png"));
        }

        public static PointStyle SportClimbing(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "sportclimbing.16.png"));
        }

        public static PointStyle SportCanoe(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "sportcanoe.16.png"));
        }

        public static PointStyle SportBaseball(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "sportbaseball.16.png"));
        }

        public static PointStyle SportArchery(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "sportarchery.16.png"));
        }

        public static PointStyle SportSkiing(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "sportskiing-downhill.16.png"));
        }

        public static PointStyle SportSwimmingCovered(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "sportswimming-indoor.16.png"));
        }

        public static PointStyle SportSwimming(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "sportswimming-outdoor.16.png"));
        }

        public static PointStyle TourismZoo(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "tourismzoo.16.png"));
        }

        public static PointStyle TourismViewpoint(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "tourismviewpoint.16.png"));
        }

        public static PointStyle TourismThemePark(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "tourismtheme_park.16.png"));
        }

        public static PointStyle TourismPicnicStie(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "tourismpicnic_site.16.png"));
        }

        public static PointStyle TourismMuseum(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "tourismmuseum.16.png"));
        }

        public static PointStyle TourismMotel(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "tourismmotel.16.png"));
        }

        public static PointStyle TourismHotel(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "tourismhotel-2.16.png"));
        }

        public static PointStyle TourismHostel(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "tourismhostel.16.png"));
        }

        public static PointStyle TourismChalet(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "tourismchalet.16.png"));
        }

        public static PointStyle TourismCaravanSite(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "tourismcaravan_site.16.png"));
        }

        public static PointStyle TourismCampSite(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "tourismcamp_site.16.png"));
        }

        public static PointStyle TourismAttraction(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "tourismattraction.16.png"));
        }

        public static PointStyle TourismArtwork(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "tourismartwork-2.16.png"));
        }

        public static PointStyle TourismAlpineHut(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "tourismalpine_hut.16.png"));
        }

        public static PointStyle TourismInformationGuidepost(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "tourisminformation-guidepost.16.png"));
        }

        public static PointStyle TourismInformationMap(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "tourisminformation-map.16.png"));
        }

        public static PointStyle TourismInformation(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "tourisminformation.16.png"));
        }

        public static PointStyle WaterwayWeir(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "waterwayweir.16.png"));
        }

        public static PointStyle AmenityCasino(string iconPath)
        {
            return ImagePointStyle(PclSystem.Path.Combine(iconPath, "amenitycasino.16.png"));
        }
    }
}