using ThinkGeo.MapSuite.Drawing;

namespace ThinkGeo.MapSuite.Styles
{
    public static class WorldStreetsTextStyles
    {
        public static TextStyle GeneralPurpose(string labelColumnName, float fontSize)
        {
            return new TextStyle(labelColumnName, new GeoFont("Verdana", fontSize), new GeoSolidBrush(new GeoColor(255, 102, 102, 102)))
            {
                HaloPen = new GeoPen(new GeoColor(200, 255, 255, 255), 3),
                DuplicateRule = LabelDuplicateRule.UnlimitedDuplicateLabels,
                ForceLineCarriage = true,
                OverlappingRule = LabelOverlappingRule.NoOverlapping,
                PolygonLabelingLocationMode = PolygonLabelingLocationMode.Centroid,
                GridSize = 0,
                FittingPolygon = true,
                SplineType = SplineType.StandardSplining,
                PointPlacement = PointPlacement.Center,
                StyleClass = "WorldMapKitTextStyles.GeneralPurpose"
            };
        }

        public static TextStyle Poi(string labelColumnName, float fontSize, int yOffsetInPixel)
        {
            return new TextStyle(labelColumnName, new GeoFont("Verdana", fontSize), new GeoSolidBrush(new GeoColor(255, 102, 102, 102)))
            {
                HaloPen = new GeoPen(new GeoColor(200, 255, 255, 255), 3),
                DuplicateRule = LabelDuplicateRule.UnlimitedDuplicateLabels,
                ForceLineCarriage = true,
                OverlappingRule = LabelOverlappingRule.NoOverlapping,
                GridSize = 0,
                PointPlacement = PointPlacement.LowerCenter,
                YOffsetInPixel = yOffsetInPixel,
                StyleClass = "WorldMapKitTextStyles.Poi"
            };
        }

        public static TextStyle Water(string nameColumnName, float fontSize)
        {
            return new TextStyle(nameColumnName, new GeoFont("Verdana", fontSize, DrawingFontStyles.Italic), new GeoSolidBrush(new GeoColor(255, 0, 102, 204)))
            {
                HaloPen = new GeoPen(new GeoColor(125, 255, 255, 255), 3),
                DuplicateRule = LabelDuplicateRule.UnlimitedDuplicateLabels,
                ForceLineCarriage = true,
                OverlappingRule = LabelOverlappingRule.NoOverlapping,
                PolygonLabelingLocationMode = PolygonLabelingLocationMode.Centroid,
                GridSize = 0,
                FittingPolygon = true,
                SplineType = SplineType.StandardSplining,
                StyleClass = "WorldMapKitTextStyles.Water"
            };
        }

        public static TextStyle MotorwayRoadSheild(string nameColumnName, float fontSize)
        {
            TextStyle textStyle = new TextStyle(nameColumnName, new GeoFont("Verdana", fontSize, DrawingFontStyles.Bold), new GeoSolidBrush(new GeoColor(255, 102, 102, 102)))
            {
                DuplicateRule = LabelDuplicateRule.OneDuplicateLabelPerQuadrant,
                ForceLineCarriage = true,
                OverlappingRule = LabelOverlappingRule.NoOverlapping,
                SplineType = SplineType.None,
                TextLineSegmentRatio = 4,
                GridSize = 0,
                ForceHorizontalLabelForLine = true,
                MaskMargin = 2,
                MaskType = MaskType.RoundedCorners,
                SuppressPartialLabels = true,
                Mask = new AreaStyle(new GeoPen(new GeoColor(255, 153, 153, 153), 2)) { DrawingLevel = DrawingLevel.LabelLevel },
                StyleClass = "WorldMapKitTextStyles.MotorwayRoadSheild"
            };

            textStyle.Mask.Advanced.FillCustomBrush = new GeoLinearGradientBrush(new GeoColor(255, 245, 200, 132), new GeoColor(255, 255, 243, 230), -90);

            return textStyle;
        }

        public static TextStyle TrunkRoadSheild(string nameColumnName, float fontSize)
        {
            TextStyle textStyle = new TextStyle(nameColumnName, new GeoFont("Verdana", fontSize, DrawingFontStyles.Bold), new GeoSolidBrush(new GeoColor(255, 102, 102, 102)))
            {
                DuplicateRule = LabelDuplicateRule.OneDuplicateLabelPerQuadrant,
                ForceLineCarriage = true,
                OverlappingRule = LabelOverlappingRule.NoOverlapping,
                SplineType = SplineType.None,
                TextLineSegmentRatio = 4,
                GridSize = 0,
                ForceHorizontalLabelForLine = true,
                MaskMargin = 2,
                MaskType = MaskType.RoundedCorners,
                SuppressPartialLabels = true,
                Mask = new AreaStyle(new GeoPen(new GeoColor(255, 153, 153, 153), 2)) { DrawingLevel = DrawingLevel.LabelLevel },
                StyleClass = "WorldMapKitTextStyles.TrunkRoadSheild"
            };

            textStyle.Mask.Advanced.FillCustomBrush = new GeoLinearGradientBrush(new GeoColor(255, 245, 218, 177), new GeoColor(255, 255, 246, 240), -90);

            return textStyle;
        }

        public static TextStyle PrimaryRoadSheild(string nameColumnName, float fontSize)
        {
            TextStyle textStyle = new TextStyle(nameColumnName, new GeoFont("Verdana", fontSize, DrawingFontStyles.Bold), new GeoSolidBrush(new GeoColor(255, 102, 102, 102)))
            {
                DuplicateRule = LabelDuplicateRule.OneDuplicateLabelPerQuadrant,
                ForceLineCarriage = true,
                OverlappingRule = LabelOverlappingRule.NoOverlapping,
                SplineType = SplineType.None,
                TextLineSegmentRatio = 4,
                GridSize = 0,
                ForceHorizontalLabelForLine = true,
                MaskMargin = 2,
                MaskType = MaskType.RoundedCorners,
                SuppressPartialLabels = true,
                Mask = new AreaStyle(new GeoPen(new GeoColor(255, 153, 153, 153), 2)) { DrawingLevel = DrawingLevel.LabelLevel },
                StyleClass = "WorldMapKitTextStyles.PrimaryRoadSheild"
            };

            textStyle.Mask.Advanced.FillCustomBrush = new GeoLinearGradientBrush(new GeoColor(255, 255, 243, 195), new GeoColor(255, 255, 253, 235), -90);

            return textStyle;
        }
    }
}